@@ -1,14 +1,20 @@
 package Spreadsheet::HTML;
 use strict;
 use warnings FATAL => 'all';
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 
 use Exporter 'import';
-our @EXPORT_OK = qw( generate portrait landscape north east south west );
+our @EXPORT_OK = qw(
+    generate portrait landscape
+    north east south west layout
+    chess checkers checkerboard
+    dk
+);
 
 use Clone;
 use HTML::AutoTag;
 use Math::Matrix;
+use Spreadsheet::HTML::Presets;
 use Spreadsheet::HTML::File::Loader;
 
 sub portrait    { generate( @_, theta =>   0 ) }
@@ -19,17 +25,11 @@ sub east    { generate( @_, theta =>   90, tgroups => 0, pinhead => 1 ) }
 sub south   { generate( @_, theta => -180, tgroups => 0, pinhead => 1 ) }
 sub west    { generate( @_, theta => -270, tgroups => 0 ) }
 
-sub layout {
-    generate( @_,
-        encodes => '',
-        matrix  => 1,
-        table   => {
-            role => 'presentation',
-            ( map {$_ => 0} qw( border cellspacing cellpadding ) ),
-        },
-        _layout => 1,
-    );
-}
+sub layout          { Spreadsheet::HTML::Presets::layout( @_ ) }
+sub chess           { Spreadsheet::HTML::Presets::chess( @_ ) }
+sub checkers        { Spreadsheet::HTML::Presets::checkers( @_ ) }
+sub checkerboard    { Spreadsheet::HTML::Presets::checkerboard( @_ ) }
+sub dk              { Spreadsheet::HTML::Presets::dk( @_ ) }
 
 sub generate {
     my %args = _process( @_ );
@@ -118,6 +118,11 @@ sub _process {
             my ( $val, $attr ) = _expand_code_or_hash( $args->{$tag}, $data->[$row][$col] );
             $args->{$tag} = [ $args->{$tag} ] unless ref( $args->{$tag} ) eq 'ARRAY';
 
+            # -rowXcolX
+            if (exists $args->{"-row${row}col${col}"}) {
+                ( $val, $attr ) = _expand_code_or_hash( $args->{"-row${row}col${col}"}, $val );
+            }
+
             # -colX
             if (exists $args->{"-col$col"}) {
                 ( $val, $attr ) = _expand_code_or_hash( $args->{"-col$col"}, $val );
@@ -287,13 +292,6 @@ sub _expand_code_or_hash {
     return ( $val, $attr );
 }
 
-sub transpose   { no warnings; warn "transpose is deprecated, use landscape";       generate( @_, theta => -270, tgroups => 0 ) }
-sub earthquake  { no warnings; warn "earthquake is deprecated, use east";           generate( @_, theta =>  90, tgroups => 0 ) }
-sub reverse     { no warnings; warn "reverse is deprecated, use south with flip";   generate( @_, theta => 180, tgroups => 0 ) }
-sub mirror      { no warnings; warn "mirror is deprecated, use portrait with flip"; generate( @_, theta =>    0, flip => 1 ) }
-sub tsunami     { no warnings; warn "tsunami is deprecated, use east with flip";    generate( @_, theta =>  -90, tgroups => 0 ) }
-sub flip        { no warnings; warn "flip is deprecated, use south";                generate( @_, theta => -180, tgroups => 0 ) }
-
 
 1;
 
@@ -383,49 +381,26 @@ because the table rows contain both headings and cells. You can override
 this behavior by using C<generate> with args listed above instead of 
 C<south()>, C<east()> or C<west()>.
 
-=item * C<layout( %args )>
-
-Layout tables are not recommended, but if you choose to
-use them you should label them as such. This adds W3C
-recommended layout attributes to the table tag and features:
-emiting only <td> tags, no padding or pruning of rows, forces
-no HTML entity encoding in table cells.
-
 =back
 
 For most cases, C<portrait()> and C<landscape()> are all you need.
 Everything else is C<bells_and_whistles>.
 
-=head2 DEPRECATED METHODS
+=head2 PRESETS
 
-These methods will be removed soon. Using them now will
-emit warning messages that inform of alternatives.
+See L<Spreadsheet::HTML::Presets> for full documentation.
 
 =over 4
 
-=item * C<transpose( %args )>
+=item * C<layout( %args )>
 
-Deprecated: use C<landscape()>
+=item * C<checkerboard( %args )>
 
-=item * C<earthquake( %args )>
+=item * C<chess( %args )>
 
-Deprecated: use C<east()>
+=item * C<checkers( %args )>
 
-=item * C<tsunami( %args )>
-
-Deprecated: use C<east( 'flip', 1 )>
-
-=item * C<mirror( %args )>
-
-Deprecated: use C<north( 'flip', 1 )>
-
-=item * C<reverse( %args )>
-
-Deprecated: use C<south( 'flip', 1 )>
-
-=item * C<flip( %args )>
-
-Deprecated: use C<south()>
+=item * C<dk( %args )>
 
 =back
 
@@ -596,6 +571,11 @@ name in that column:
 Override headings with either C<headings> or C<th> or indirectly
 with <thead> via CSS definitions for a class you assign.
 
+=item * C<-rowXcolX>
+
+Apply this anonymous subroutine or hash ref of attributres
+to the cell at row X and column X.  (0 index based)
+
 =item * C<caption>
 
 Caption is special in that you can either pass a string to
