@@ -14,7 +14,7 @@ sub parse {
         return Spreadsheet::HTML::File::JSON::parse( $file );
     } elsif ($file =~ /\.ya?ml$/) {
         return Spreadsheet::HTML::File::YAML::parse( $file );
-    } elsif ($file =~ /\.xls$/) {
+    } elsif ($file =~ /\.xlsx?$/) {
         return Spreadsheet::HTML::File::XLS::parse( $file );
     }
 }
@@ -128,9 +128,10 @@ our $NOT_AVAILABLE = $@;
 
 sub parse {
     my $file = shift;
-    open my $fh, '<', $file or return [[ "cannot load $file" ],[ $! ]];
+    return [[ "cannot load $file" ],[ 'No such file or directory' ]] unless -r $file;
     return [[ "cannot load $file" ],[ 'please install JSON' ]] if $NOT_AVAILABLE;
 
+    open my $fh, '<', $file or return [[ "cannot load $file" ],[ $! ]];
     my $data = decode_json( do{ local $/; <$fh> } );
     close $fh;
     return $data;
@@ -181,6 +182,7 @@ if ($@) {
 sub parse {
     my @data;
     my $file = shift;
+    return [[ "cannot load $file" ],[ 'No such file or directory' ]] unless -r $file;
 
     open my $fh, '<', $file or return [[ "cannot load $file" ],[ $! ]];
 
